@@ -524,6 +524,7 @@ async fn handle_block_scroll(app: &mut App, up: bool, is_mouse: bool, page: bool
   }
 }
 
+#[cfg(target_arch = "x86_64")]
 fn copy_to_clipboard(content: String) {
   use clipboard::{ClipboardContext, ClipboardProvider};
 
@@ -533,6 +534,11 @@ fn copy_to_clipboard(content: String) {
     .expect("Unable to set content to clipboard");
 }
 
+#[cfg(any(target_arch = "aarch64", target_arch = "arm"))]
+fn copy_to_clipboard(_content: String) {
+  // do nothing as its a PITA to compile for ARM with XCB and this feature is not that important
+}
+
 /// inverse direction for natural scrolling on mouse and keyboard
 fn inverse_dir(up: bool, is_mouse: bool) -> bool {
   if is_mouse {
