@@ -29,9 +29,11 @@ static REPLICA_SETS_TITLE: &str = "ReplicaSets";
 static DEPLOYMENTS_TITLE: &str = "Deployments";
 static JOBS_TITLE: &str = "Jobs";
 static DAEMON_SETS_TITLE: &str = "DaemonSets";
-static CRON_JOBS_TITLE: &str = "Cron Jobs";
+static CRON_JOBS_TITLE: &str = "CronJobs";
 static SECRETS_TITLE: &str = "Secrets";
 static RPL_CTRL_TITLE: &str = "ReplicationControllers";
+static STORAGE_CLASSES_LABEL: &str = "StorageClasses";
+static ROLES_TITLE: &str = "Roles";
 static DESCRIBE_ACTIVE: &str = "-> Describe ";
 static YAML_ACTIVE: &str = "-> YAML ";
 
@@ -80,6 +82,8 @@ fn draw_more<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App
     ActiveBlock::CronJobs => draw_cronjobs_tab(block, f, app, area),
     ActiveBlock::Secrets => draw_secrets_tab(block, f, app, area),
     ActiveBlock::RplCtrl => draw_replication_controllers_tab(block, f, app, area),
+    ActiveBlock::StorageClasses => draw_storage_classes_tab(block, f, app, area),
+    ActiveBlock::Roles => draw_roles_tab(block, f, app, area),
     ActiveBlock::Describe | ActiveBlock::Yaml => {
       let mut prev_route = app.get_prev_route();
       if prev_route.active_block == block {
@@ -89,6 +93,8 @@ fn draw_more<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App
         ActiveBlock::CronJobs => draw_cronjobs_tab(block, f, app, area),
         ActiveBlock::Secrets => draw_secrets_tab(block, f, app, area),
         ActiveBlock::RplCtrl => draw_replication_controllers_tab(block, f, app, area),
+        ActiveBlock::StorageClasses => draw_storage_classes_tab(block, f, app, area),
+        ActiveBlock::Roles => draw_roles_tab(block, f, app, area),
         _ => { /* do nothing */ }
       }
     }
@@ -287,7 +293,11 @@ fn draw_nodes_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mu
       app,
       area,
       title_with_dual_style(
-        get_node_title(app, get_describe_active(block)),
+        get_cluster_wide_resource_title(
+          NODES_TITLE,
+          app.data.nodes.items.len(),
+          get_describe_active(block),
+        ),
         format!("{} | {} <esc> ", COPY_HINT, NODES_TITLE),
         app.light_theme,
       ),
@@ -298,7 +308,7 @@ fn draw_nodes_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mu
 }
 
 fn draw_nodes_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
-  let title = get_node_title(app, "");
+  let title = get_cluster_wide_resource_title(NODES_TITLE, app.data.nodes.items.len(), "");
 
   draw_resource_block(
     f,
@@ -939,6 +949,114 @@ fn draw_replication_controllers_block<B: Backend>(f: &mut Frame<'_, B>, app: &mu
   );
 }
 
+fn draw_storage_classes_tab<B: Backend>(
+  block: ActiveBlock,
+  f: &mut Frame<'_, B>,
+  app: &mut App,
+  area: Rect,
+) {
+  draw_resource_tab!(
+    STORAGE_CLASSES_LABEL,
+    block,
+    f,
+    app,
+    area,
+    draw_storage_classes_tab,
+    draw_storage_classes_block,
+    app.data.storage_classes
+  );
+}
+
+fn draw_storage_classes_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  let title = get_cluster_wide_resource_title(
+    STORAGE_CLASSES_LABEL,
+    app.data.storage_classes.items.len(),
+    "",
+  );
+
+  draw_resource_block(
+    f,
+    area,
+    ResourceTableProps {
+      title,
+      inline_help: DESCRIBE_YAML_AND_ESC_HINT.into(),
+      resource: &mut app.data.storage_classes,
+      table_headers: vec![
+        "Name",
+        "Provisioner",
+        "Reclaim Policy",
+        "Volume Binding Mode",
+        "Allow Volume Expansion",
+        "Age",
+      ],
+      column_widths: vec![
+        Constraint::Percentage(10),
+        Constraint::Percentage(20),
+        Constraint::Percentage(10),
+        Constraint::Percentage(20),
+        Constraint::Percentage(20),
+        Constraint::Percentage(10),
+      ],
+    },
+    |c| {
+      Row::new(vec![
+        Cell::from(c.name.to_owned()),
+        Cell::from(c.provisioner.to_owned()),
+        Cell::from(c.reclaim_policy.to_owned()),
+        Cell::from(c.volume_binding_mode.to_owned()),
+        Cell::from(c.allow_volume_expansion.to_string()),
+        Cell::from(c.age.to_owned()),
+      ])
+      .style(style_primary(app.light_theme))
+    },
+    app.light_theme,
+    app.is_loading,
+  );
+}
+
+fn draw_roles_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  draw_resource_tab!(
+    ROLES_TITLE,
+    block,
+    f,
+    app,
+    area,
+    draw_roles_tab,
+    draw_roles_block,
+    app.data.roles
+  );
+}
+
+fn draw_roles_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  let title = get_resource_title(app, ROLES_TITLE, "", app.data.roles.items.len());
+
+  draw_resource_block(
+    f,
+    area,
+    ResourceTableProps {
+      title,
+      inline_help: DESCRIBE_YAML_AND_ESC_HINT.into(),
+      resource: &mut app.data.roles,
+      table_headers: vec!["Namespace", "Name", "Age"],
+      column_widths: vec![
+        Constraint::Percentage(40),
+        Constraint::Percentage(40),
+        Constraint::Percentage(20),
+      ],
+    },
+    |c| {
+      Row::new(vec![
+        Cell::from(c.namespace.to_owned()),
+        Cell::from(c.name.to_owned()),
+        Cell::from(c.age.to_owned()),
+      ])
+      .style(style_primary(app.light_theme))
+    },
+    app.light_theme,
+    app.is_loading,
+  );
+}
+
 /// common for all resources
 fn draw_describe_block<B: Backend>(
   f: &mut Frame<'_, B>,
@@ -1028,13 +1146,8 @@ fn get_resource_row_style(status: &str, ready: (i32, i32), light: bool) -> Style
   }
 }
 
-fn get_node_title<S: AsRef<str>>(app: &App, suffix: S) -> String {
-  format!(
-    " {} [{}] {}",
-    NODES_TITLE,
-    app.data.nodes.items.len(),
-    suffix.as_ref()
-  )
+fn get_cluster_wide_resource_title<S: AsRef<str>>(title: S, items_len: usize, suffix: S) -> String {
+  format!(" {} [{}] {}", title.as_ref(), items_len, suffix.as_ref())
 }
 
 fn get_resource_title<S: AsRef<str>>(app: &App, title: S, suffix: S, items_len: usize) -> String {
@@ -1342,12 +1455,6 @@ mod tests {
     terminal.backend().assert_buffer(&expected);
   }
 
-  #[test]
-  fn test_get_node_title() {
-    let app = App::default();
-    assert_eq!(get_node_title(&app, "-> hello"), " Nodes [0] -> hello");
-  }
-
   #[test]
   fn test_get_resource_title() {
     let app = App::default();
@@ -1370,4 +1477,16 @@ mod tests {
   fn test_title_with_ns() {
     assert_eq!(title_with_ns("Title", "hello", 3), "Title (ns: hello) [3]");
   }
+
+  #[test]
+  fn test_get_cluster_wide_resource_title() {
+    assert_eq!(
+      get_cluster_wide_resource_title("Cluster Resource", 3, ""),
+      " Cluster Resource [3] "
+    );
+    assert_eq!(
+      get_cluster_wide_resource_title("Nodes", 10, "-> hello"),
+      " Nodes [10] -> hello"
+    );
+  }
 }
